summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLamont Granquist <lamont@scriptkiddie.org>2020-04-16 15:19:27 -0700
committerLamont Granquist <lamont@scriptkiddie.org>2020-04-16 15:19:27 -0700
commitfdde344fbac08a4b3146d7ed2e683f763e4a0fe3 (patch)
tree4048615c48b4ebee8836099a14f2788655643af5
parentf00876f46b3a07e642181c9d439863e4ebe16403 (diff)
downloadchef-lcg/bootstrap-options-cleanup.tar.gz
missed two references to base_mixlib_configlcg/bootstrap-options-cleanup
Signed-off-by: Lamont Granquist <lamont@scriptkiddie.org>
-rw-r--r--lib/chef/knife.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/chef/knife.rb b/lib/chef/knife.rb
index 73d33f30a9..bdab024579 100644
--- a/lib/chef/knife.rb
+++ b/lib/chef/knife.rb
@@ -347,7 +347,7 @@ class Chef
# values here (the set values are explicitly mixed in again later), but there is
# no mixlib-config API to get a Hash back with only the default values.
#
# Assumption: since base_mixlib_config is the lowest precedence it doesn't matter
# that we include the set values here, but this is a hack and makes the name of the
# method a lie. FIXME: make the name not a lie by adding an API to mixlib-config.
#
@@ -399,7 +399,7 @@ class Chef
return :cli if @original_config.include? key
return :config if config_file_settings.key? key
return :cli_default if default_config.include? key
- return :config_default if base_mixlib_config.key? key # must come after :config check
+ return :config_default if config_file_defaults.key? key # must come after :config check
nil
end
@@ -347,7 +347,7 @@ class Chef
# no mixlib-config API to get a Hash back with only the default values.
#
- # Assumption: since base_mixlib_config is the lowest precedence it doesn't matter
+ # Assumption: since config_file_defaults is the lowest precedence it doesn't matter
# that we include the set values here, but this is a hack and makes the name of the
# method a lie. FIXME: make the name not a lie by adding an API to mixlib-config.